pub struct MyEvm<CTX, INSP> {
pub ctx: CTX,
pub inspector: INSP,
pub instruction: EthInstructions<EthInterpreter, CTX>,
pub precompiles: EthPrecompiles,
pub frame_stack: FrameStack<MyFrame>,
}Expand description
Fields
ctx: CTXContextTr of the EVM, it is used to fetch data from database.
inspector: INSPInspector of the EVM it is used to inspect the EVM. Its trait are defined in revm-inspector crate.
instruction: EthInstructions<EthInterpreter, CTX>Instructions provider of the EVM it is used to execute instructions.
InstructionProvider trait is defined in revm-handler crate.
precompiles: EthPrecompilesPrecompile provider of the EVM it is used to execute precompiles.
PrecompileProvider trait is defined in revm-handler crate.
frame_stack: FrameStack<MyFrame>The custom frame stack that is going to be executed.
Implementations